@@ -20,7 +20,7 @@
  *
  * @author     Ryuma Ando <ando@ecomas.co.jp>
  * @copyright  2003-2008 PgPool Global Development Group
- * @version    CVS: $Id: ja.lang.php,v 1.15 2009/12/08 02:13:58 t-ishii Exp $
+ * @version    CVS: $Id: ja.lang.php,v 1.21 2010/08/16 10:06:42 t-ishii Exp $
  */
 
 $message = array(
@@ -31,16 +31,19 @@ $message = array(
     'descBackend_socket_dir' => 'PostgreSQLサーバのUnix domain socketのディレクトリ',
     'descBackend_weight' => 'ロードバランスモード時のSELECTを振り分ける「重み」の定義',
     'descBackend_data_directory' => 'PostgreSQLサーバのデータベースディレクトリ',
+    'descBlack_function_list' => 'データベースに書き込みを行なうカンマ区切りの関数のリスト',
     'descChild_life_time' => 'pgpoolの子プロセスの寿命',
     'descChild_max_connections' => '各pgpool子プロセスが終了するまでの接続回数',
 	'descClient_idle_limit' => 'クライアントからのクエリの最大待ち時間(秒)',
 	'descAuthentication_timeout' => 'クライアント認証のタイムアウト時間(秒)',
     'descConnection_cache' => 'コネクションキャッシュ機能の有無',
     'descConnection_life_time' => 'コネクションプール中のコネクションの有効期間(秒)',
+    'descDelay_threshold' => '許容するスタンバイサーバの遅延(バイト)',
 	'descEnable_pool_hba' => 'クライアント認証機能の有無',
     'descEnable_query_cache' => 'クエリキャッシュ機能の有無',
     'descFailover_command' => 'ノード切り離し時に起動するコマンド',
     'descFailback_command' => 'ノード復帰時に起動するコマンド',
+    'descFailover_if_affected_tuples_mismatch' => '更新行数が一致しないときにフェイルオーバ',
     'descFail_over_on_backend_error' => 'DBノードへのソケット通信エラー時にフェイルオーバ',
     'descHealth_check_period' => 'ヘルスチェックを行う間隔(秒)',
     'descHealth_check_timeout' => 'ヘルスチェックが長時間待たされるのを防ぐためのタイムアウト値(秒)',
@@ -49,13 +52,16 @@ $message = array(
     'descInsert_lock' => 'INSERT時に自動的にトランザクションの開始，テーブルロック，トランザクションの終了',
     'descListen_addresses' => 'TCP/IPコネクションを受け付けるアドレス',
     'descLoad_balance_mode' => 'レプリケーションモード時にSELECT文を各ノードにロードバランス',
+    'descLobj_lock_table' => 'ラージオブジェクトのレプリケーションでロック管理に使うためのテーブル名',
 	'descLog_connections' => '受信した接続のログを出力',
 	'descLog_hostname' => 'クライアントのホスト名を"ps"ステータスに出力',
+    'descLog_standby_delay' => 'スタンバイサーバの遅延をログに記録する',
     'descLog_statement' => 'SQL文をログ出力',
     'descLogdir' => 'pgpoolの各種ログファイルを格納するディレクトリ',
     'descLog_per_node_statement' => 'DBノード毎にSQL文をログ出力',
     'descPid_file_name' => 'pidファイルの名前',
     'descMaster_slave_mode' => 'マスタ/スレーブモードでpgpoolを運転',
+    'descMaster_slave_sub_mode' => 'マスタ/スレーブモードの伝播方法',
     'descMax_pool' => 'pgpoolの各サーバプロセスがキープするPostgreSQLへの最大コネクション数',
     'descNum_init_children' => 'preforkするpgpoolのサーバプロセス数',
     'descParallel_mode' => 'パラレルモードでpgpoolを運転',
@@ -76,6 +82,11 @@ $message = array(
 	'descReplicate_select' => 'SELECT 文のレプリケーション',
     'descReplication_timeout' => 'デッドロックを監視するためのタイムアウト時間',
     'descReset_query_list' => 'セッションが終了するときにコネクションを初期化するためのSQLコマンド',
+    'descSsl' => 'pgpool-IIとバックエンドの間のSSL接続',
+    'descSsl_ca_cert' => 'opensslの-CAFileに指定するパス',
+    'descSsl_ca_cert_dir' => 'opensslの-CApathに指定するディレクトリパス',
+    'descSsl_cert' => 'フロントエンドとの接続に使用する公開x509証明書のフルパス',
+    'descSsl_key' => 'フロントエンドとの接続に使用するプライベートキーファイルのフルパス',
     'descSocket_dir' => 'pgpoolがコネクションを受け付けるUnix domain socketディレクトリ',
     'descSystem_db_dbname' => 'System DBのデータベース名',
     'descSystem_db_hostname' => 'System DBが動いているホスト名',
@@ -83,6 +94,7 @@ $message = array(
     'descSystem_db_port' => 'System DBに接続するためのポート番号',
     'descSystem_db_schema' => 'System DBのスキーマ',
     'descSystem_db_user' => 'System DBに接続するときのユーザ名',
+    'descWhite_function_list' => 'データベースに書き込みを行なわないカンマ区切りの関数のリスト',
     'errAlreadyExist' => 'すでに登録されています',
     'errFileNotExecutable' => 'コマンドを実行できません',
     'errFileNotFound' => 'ファイルが見つかりません',
@@ -109,9 +121,13 @@ $message = array(
     'msgStopPgpool' => 'pgpoolを停止してよいですか？',
     'msgUpdateComplete' => '更新は正常に終了しました',
     'msgUpdateFailed' => '更新に失敗しました',
+    'msgDetachConfirm' => 'このノードを切断してよいですか？',
+    'msgReturnConfirm' => 'このノードを復帰させてよいですか？',
+    'msgRecoveryConfirm' => 'このノードをリカバリしますか？',
     'strAdd' => '追加',
     'strAdminPassword' => '管理者パスワード',
     'strBack' => '戻る',
+    'strBackendPid' => 'バックエンドプロセスID',
     'strCancel' => 'キャンセル',
     'strChangePassword' => 'パスワード変更',
     'strClear' => 'クリア',
@@ -119,6 +135,7 @@ $message = array(
     'strCmdC' => 'クエリキャッシュクリア',
     'strCmdD' => 'デバッグモード',
     'strCmdDesc' => '空白の場合には無視',
+    'strCmdLargeD' => 'pgpool_status を無視',
     'strCmdM' => '停止モード',
     'strCmdN' => '非デーモンモード',
     'strCmdPcpFile' => 'pcp.conf',
@@ -148,6 +165,7 @@ $message = array(
     'strErrorMessage' => 'エラーメッセージ',
     'strExecute' => '実行',
     'strFeature' => '機能',
+    'strFrontendConnected' => 'フロントエンド接続有無',
     'strHealthCheck' => 'ヘルスチェック',
     'strHelp' => 'ヘルプ',
     'strInvalidation' => '無効',
@@ -159,11 +177,12 @@ $message = array(
     'strLoginName' => 'ログイン名',
     'strLogout' => 'ログアウト',
     'strMasterServer' => 'マスターサーバ',
+    'strMasterSlaveMode' => 'マスタースレーブモード',
     'strMeasures' => '対策',
     'strNodeInfo' => 'ノード情報',
     'strNodeStatus' => 'ノードステータス',
-    'strNodeStatus1' => 'ノード稼働中。接続無し',
-    'strNodeStatus2' => 'ノード稼働中。接続有り',
+    'strNodeStatus1' => 'ノード稼働中。接続無し。',
+    'strNodeStatus2' => 'ノード稼働中。接続有り。',
     'strNodeStatus3' => 'ノードダウン',
     'strNoNode' => 'ノードがありません',
     'strOff' => 'オフ',
@@ -192,6 +211,7 @@ $message = array(
     'strPgpoolSummary' => 'サマリー',
     'strPleaseWait' => 'しばらくお待ちください・・・',
     'strPort' => 'ポート',
+    'strPrimaryRunning' => 'プライマリとして稼働中',
     'strProcId' => 'プロセスID',
     'strProcInfo' => 'プロセス情報',
     'strProcTime' => 'プロセススタート時刻',
@@ -212,11 +232,14 @@ $message = array(
     'strSecondaryServer' => 'セカンダリサーバ',
     'strSetting' => '管理ツール設定',
     'strSetup' => 'セットアップ',
+    'strSlonyMode' => 'Slony-Iモード',
+    'strStandbyRunning' => 'スタンバイとして稼働中',
     'strStartOption' => '起動オプション',
     'strStartPgpool' => 'pgpool起動',
     'strStatus' => 'ステータス',
     'strStopOption' => 'pgpool停止オプション',
     'strStopPgpool' => 'pgpool停止',
+    'strStreamingRepMode' => 'Streaming Replicationモード',
     'strSummary' => '概要',
     'strSystemDb' => '分散ルール',
     'strTable' => 'テーブル名',
